#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-4BxCKYEvKU0JctI5cQ2N9C
key:                  ghcide-2.3.0.0-4BxCKYEvKU0JctI5cQ2N9C
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  c345f136666e226efd07d4766101c987
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-4BxCKYEvKU0JctI5cQ2N9C
depends:
    Diff-1.0-EvgcRbKZWqFCXRWb450FiY Glob-0.10.2-32Dqf0gzO1o2gDqSrGQ6hJ
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z array-0.5.6.0
    async-2.2.6-ClOW2oFWjQTDZxVKjsrmlu base-4.18.2.1
    base16-bytestring-1.0.2.0-KkKTvweYtUjAEl7m2QLWFY binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-A8CTHJLbf7AArK6CnJHSQw
    co-log-core-0.3.2.7-EX9bfD1TsuICOc9Y4qQoer containers-0.6.7
    cryptohash-sha1-0.11.101.0-Ah8gZa7EYGY3jjcblccB4t
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    dependent-map-0.4.0.1-LECADgMoI5vI8JoKuW6eDn
    dependent-sum-0.7.2.0-FKUAu3RzfwZ6WRgt5dShmm directory-1.3.8.5
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp
    enummapset-0.7.3.0-Go9liWXzhOe3iOhWL9pdye exceptions-0.10.7
    extra-1.7.16-aWEq6cZZ289lIc6yxljo5 filepath-1.4.300.1
    fingertree-0.1.6.3-84EQR4WQHqDF0liaZnfVbA
    focus-1.0.3.2-K4r8d6TYSaL8JgI7TgFd9X ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-xTcFC8r40LA8r0lrs4mdI
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-5y8YoPHCTMmL3bN3mQjDOV
    hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    hie-bios-0.12.0-9LZjTbKos99kepC8phEe3
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-LOEUIBEoqo127RIdL6Lh7O
    hls-graph-2.3.0.0-BRVDJeez42v59y3yOWOoxM
    hls-plugin-api-2.3.0.0-BCHQWahc8F3AkxNmAzYlVI
    implicit-hie-0.1.4.0-54F2vlnFySv7u5IeRqx8RQ
    implicit-hie-cradle-0.5.0.1-LKs30o7ilhm6e7gZcfJi2b
    lens-5.3.5-JKPJsUIkx0YEZ4W3JntdKw
    list-t-1.0.5.7-5wiNHt4HfJY6yigEbdj2d7
    lsp-2.2.0.0-AMvH8uI6CvNFs6ZEiC2ocP
    lsp-types-2.0.2.0-FxqOKdDzvom3LxZERPn3Y4 mtl-2.3.1
    opentelemetry-0.8.0-9CFgovYUXVgFJGpWG7zL4g
    optparse-applicative-0.18.1.0-5QX38E1JQlq4e4oHsAaFH0
    parallel-3.3.0.0-777lW8EKp7RLYem9SqDKwn
    prettyprinter-1.7.2-6Ih5s8mp5Rq22RoHimn1zv
    prettyprinter-ansi-terminal-1.1.4-FXq630JFUaVDqXZsF8pB5L
    random-1.2.1.3-FxwYxgjgoojJKMc450MWAC
    regex-tdfa-1.3.2.5-K3WM9QKkG8i6YZ8c6M2glc
    row-types-1.0.1.2-7y1Qreup7EcIjbCr0wThpi
    safe-exceptions-0.1.7.4-LLCsXRZv4m2CGwiR6DBSct
    sorted-list-0.2.3.1-Al3fq5BgiImHmKpJ23gC10
    sqlite-simple-0.4.19.0-C0RNFTcVgtw5U6bFPwgDl1 stm-2.5.1.0
    stm-containers-1.2.2-ImRytgGzpwD6j3sGQ7LQ10
    syb-0.7.4-CWkOfF6Y0mt62kPybHOEB1 text-2.0.2
    text-rope-0.3-GsIy2VEd062h6a3Ns2xvL time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-95hsWJFispi2AzgK8xFJw
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

